==> estateplat-common-1.2.3-20180329.032146-54-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 *  房屋所有权
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_FWSYQ")
public class GdFwsyq implements Serializable {
    @Id
    private String qlid;
    private String fczh;
	private Integer iszx;
	private String djlx;
	private String djyy;
	private String proid;

    private String fj;
	private Date gxrq;
	private String zslx;
	private String cjrid;//创建人ID
	private String yqzh;//原权证号
	private String bz;//备注


	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25,
	 * @description
	 */
	private Double dytdmj;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25
	 * @description 分摊土地面积，用于没有关联土地证或土地证书上分摊土地面积不准确的情况
	 */
	private Double fttdmj;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25
	 * @description 土地使用权面积，记录既有独用又有分摊的情况
	 */
	private Double tdsyqmj;

	private String tdqsxz;//土地权属性质
	private String tdyt;//土地用途
	private Date tdsyksrq;//土地使用权开始日期
	private Date tdsyjsrq;//土地使用权结束日期
	private String tdsyqlx;//土地使用权类型
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/8/3
	 * @description 档案业务号，用于挂接过渡房产登记数据的档案材料信息
	 */
	private String daywh;
	private String zxdaywh;//注销档案业务号
	private Date djsj;//登记时间
	private String dbr;//登薄人
	private String zxyy;//注销原因
	private String zxdbr;//注销登簿人
	private Date zxdbsj;//注销登薄时间

	private String qllx;
	private String fwsx;//房屋属性
	private String zxdaywh;//注销档案业务
	public String getZxdaywh() {
		return zxdaywh;
	}

	public void setZxdaywh(String zxdaywh) {
		this.zxdaywh = zxdaywh;
	}

	public String getZxyy() {
		return zxyy;
	}

	public void setZxyy(String zxyy) {
		this.zxyy = zxyy;
	}

	public String getZxdbr() {
		return zxdbr;
	}

	public void setZxdbr(String zxdbr) {
		this.zxdbr = zxdbr;
	}

	public Date getZxdbsj() {
		return zxdbsj;
	}

	public void setZxdbsj(Date zxdbsj) {
		this.zxdbsj = zxdbsj;
	}


	public String getBz() {
		return bz;
	}

	public void setBz(String bz) {
		this.bz = bz;
	}

	private Date lzrq;//领证日期

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getZslx() {
		return zslx;
	}

	public void setZslx(String zslx) {
		this.zslx = zslx;
	}

	public String getCjrid() {
		return cjrid;
	}

	public void setCjrid(String cjrid) {
		this.cjrid = cjrid;
	}

	public String getYqzh() {
		return yqzh;
	}

	public void setYqzh(String yqzh) {
		this.yqzh = yqzh;
	}

	public String getQlid() {
		return qlid;
	}

	public void setQlid(String qlid) {
		this.qlid = qlid;
	}

	public String getFczh() {
		return fczh;
	}

	public void setFczh(String fczh) {
		this.fczh = fczh;
	}



	public Integer getIszx() {
		return iszx;
	}

	public void setIszx(Integer iszx) {
		this.iszx = iszx;
	}

	public String getDjlx() {
		return djlx;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public Date getLzrq() {
		return lzrq;
	}

	public void setLzrq(Date lzrq) {
		this.lzrq = lzrq;
	}

	public Double getFttdmj() {
		return fttdmj;
	}

	public void setFttdmj(Double fttdmj) {
		this.fttdmj = fttdmj;
	}

	public Double getTdsyqmj() {
		return tdsyqmj;
	}

	public void setTdsyqmj(Double tdsyqmj) {
		this.tdsyqmj = tdsyqmj;
	}

	public Double getDytdmj() {
		return dytdmj;
	}

	public void setDytdmj(Double dytdmj) {
		this.dytdmj = dytdmj;
	}

	public String getTdqsxz() {
		return tdqsxz;
	}

	public void setTdqsxz(String tdqsxz) {
		this.tdqsxz = tdqsxz;
	}

	public String getTdyt() {
		return tdyt;
	}

	public void setTdyt(String tdyt) {
		this.tdyt = tdyt;
	}

	public Date getTdsyksrq() {
		return tdsyksrq;
	}

	public void setTdsyksrq(Date tdsyksrq) {
		this.tdsyksrq = tdsyksrq;
	}

	public Date getTdsyjsrq() {
		return tdsyjsrq;
	}

	public void setTdsyjsrq(Date tdsyjsrq) {
		this.tdsyjsrq = tdsyjsrq;
	}

	public String getTdsyqlx() {
		return tdsyqlx;
	}

	public void setTdsyqlx(String tdsyqlx) {
		this.tdsyqlx = tdsyqlx;
	}

	public String getDaywh() {
		return daywh;
	}

	public void setDaywh(String daywh) {
		this.daywh = daywh;
	}

	public Date getDjsj() {
		return djsj;
	}

	public void setDjsj(Date djsj) {
		this.djsj = djsj;
	}

	public String getDbr() {
		return dbr;
	}

	public void setDbr(String dbr) {
		this.dbr = dbr;
	}

	public String getQllx() {
		return qllx;
	}

	public void setQllx(String qllx) {
		this.qllx = qllx;
	}

	public String getFwsx() {
		return fwsx;
	}

	public void setFwsx(String fwsx) {
		this.fwsx = fwsx;
	}

	public String getZxdaywh() {
		return zxdaywh;
	}

	public void setZxdaywh(String zxdaywh) {
		this.zxdaywh = zxdaywh;
	}
}

==> estateplat-common-1.2.3-20180911.110946-181-sources.jar: cn/gtmap/estateplat/model/server/core/GdFwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 *  房屋所有权
 * @author <a href="mailto:zhaodongdong@gtmap.cn">zdd</a>
 * @version V1.0, 15-4-19
 */
@Table(name = "GD_FWSYQ")
public class GdFwsyq implements Serializable {
    @Id
    private String qlid;
    private String fczh;
	private Integer iszx;
	private String djlx;
	private String djyy;
	private String proid;

    private String fj;
	private Date gxrq;
	private String zslx;
	private String cjrid;//创建人ID
	private String yqzh;//原权证号
	private String bz;//备注

	//增加冗余字段
	private String qlr;//权利人
	private String zl;//坐落
	private String qlrzjzl;//权利人证件种类
	private String qlrzjh;//权利人证件号
	private String bdcdybh;//不动产单元编号

	public String getQlr() {
		return qlr;
	}

	public void setQlr(String qlr) {
		this.qlr = qlr;
	}

	public String getZl() {
		return zl;
	}

	public void setZl(String zl) {
		this.zl = zl;
	}

	public String getQlrzjzl() {
		return qlrzjzl;
	}

	public void setQlrzjzl(String qlrzjzl) {
		this.qlrzjzl = qlrzjzl;
	}

	public String getQlrzjh() {
		return qlrzjh;
	}

	public void setQlrzjh(String qlrzjh) {
		this.qlrzjh = qlrzjh;
	}

	public String getBdcdybh() {
		return bdcdybh;
	}

	public void setBdcdybh(String bdcdybh) {
		this.bdcdybh = bdcdybh;
	}



	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25,
	 * @description
	 */
	private Double dytdmj;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25
	 * @description 分摊土地面积，用于没有关联土地证或土地证书上分摊土地面积不准确的情况
	 */
	private Double fttdmj;
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/6/25
	 * @description 土地使用权面积，记录既有独用又有分摊的情况
	 */
	private Double tdsyqmj;

	private String tdqsxz;//土地权属性质
	private String tdyt;//土地用途
	private Date tdsyksrq;//土地使用权开始日期
	private Date tdsyjsrq;//土地使用权结束日期
	private String tdsyqlx;//土地使用权类型
	/**
	 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
	 * @version 1.0, 2016/8/3
	 * @description 档案业务号，用于挂接过渡房产登记数据的档案材料信息
	 */
	private String daywh;
	private Date djsj;//登记时间
	private String dbr;//登薄人
	private String zxyy;//注销原因
	private String zxdbr;//注销登簿人
	private Date zxdbsj;//注销登薄时间

	private String qllx;
	private String fwsx;//房屋属性
	private String zxdaywh;//注销档案业务
	public String getZxyy() {
		return zxyy;
	}

	public void setZxyy(String zxyy) {
		this.zxyy = zxyy;
	}

	public String getZxdbr() {
		return zxdbr;
	}

	public void setZxdbr(String zxdbr) {
		this.zxdbr = zxdbr;
	}

	public Date getZxdbsj() {
		return zxdbsj;
	}

	public void setZxdbsj(Date zxdbsj) {
		this.zxdbsj = zxdbsj;
	}


	public String getBz() {
		return bz;
	}

	public void setBz(String bz) {
		this.bz = bz;
	}

	private Date lzrq;//领证日期

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getZslx() {
		return zslx;
	}

	public void setZslx(String zslx) {
		this.zslx = zslx;
	}

	public String getCjrid() {
		return cjrid;
	}

	public void setCjrid(String cjrid) {
		this.cjrid = cjrid;
	}

	public String getYqzh() {
		return yqzh;
	}

	public void setYqzh(String yqzh) {
		this.yqzh = yqzh;
	}

	public String getQlid() {
		return qlid;
	}

	public void setQlid(String qlid) {
		this.qlid = qlid;
	}

	public String getFczh() {
		return fczh;
	}

	public void setFczh(String fczh) {
		this.fczh = fczh;
	}



	public Integer getIszx() {
		return iszx;
	}

	public void setIszx(Integer iszx) {
		this.iszx = iszx;
	}

	public String getDjlx() {
		return djlx;
	}

	public void setDjlx(String djlx) {
		this.djlx = djlx;
	}

	public String getDjyy() {
		return djyy;
	}

	public void setDjyy(String djyy) {
		this.djyy = djyy;
	}

	public String getFj() {
		return fj;
	}

	public void setFj(String fj) {
		this.fj = fj;
	}

	public Date getGxrq() {
		return gxrq;
	}

	public void setGxrq(Date gxrq) {
		this.gxrq = gxrq;
	}

	public Date getLzrq() {
		return lzrq;
	}

	public void setLzrq(Date lzrq) {
		this.lzrq = lzrq;
	}

	public Double getFttdmj() {
		return fttdmj;
	}

	public void setFttdmj(Double fttdmj) {
		this.fttdmj = fttdmj;
	}

	public Double getTdsyqmj() {
		return tdsyqmj;
	}

	public void setTdsyqmj(Double tdsyqmj) {
		this.tdsyqmj = tdsyqmj;
	}

	public Double getDytdmj() {
		return dytdmj;
	}

	public void setDytdmj(Double dytdmj) {
		this.dytdmj = dytdmj;
	}

	public String getTdqsxz() {
		return tdqsxz;
	}

	public void setTdqsxz(String tdqsxz) {
		this.tdqsxz = tdqsxz;
	}

	public String getTdyt() {
		return tdyt;
	}

	public void setTdyt(String tdyt) {
		this.tdyt = tdyt;
	}

	public Date getTdsyksrq() {
		return tdsyksrq;
	}

	public void setTdsyksrq(Date tdsyksrq) {
		this.tdsyksrq = tdsyksrq;
	}

	public Date getTdsyjsrq() {
		return tdsyjsrq;
	}

	public void setTdsyjsrq(Date tdsyjsrq) {
		this.tdsyjsrq = tdsyjsrq;
	}

	public String getTdsyqlx() {
		return tdsyqlx;
	}

	public void setTdsyqlx(String tdsyqlx) {
		this.tdsyqlx = tdsyqlx;
	}

	public String getDaywh() {
		return daywh;
	}

	public void setDaywh(String daywh) {
		this.daywh = daywh;
	}

	public Date getDjsj() {
		return djsj;
	}

	public void setDjsj(Date djsj) {
		this.djsj = djsj;
	}

	public String getDbr() {
		return dbr;
	}

	public void setDbr(String dbr) {
		this.dbr = dbr;
	}

	public String getQllx() {
		return qllx;
	}

	public void setQllx(String qllx) {
		this.qllx = qllx;
	}

	public String getFwsx() {
		return fwsx;
	}

	public void setFwsx(String fwsx) {
		this.fwsx = fwsx;
	}

	public String getZxdaywh() {
		return zxdaywh;
	}

	public void setZxdaywh(String zxdaywh) {
		this.zxdaywh = zxdaywh;
	}
}
